@@ -31,11 +31,9 @@
 
 #include "animation.h"
 
-static void      clearlooks_rc_style_init         (ClearlooksRcStyle      *style);
 #ifdef HAVE_ANIMATION
 static void      clearlooks_rc_style_finalize     (GObject                *object);
 #endif
-static void      clearlooks_rc_style_class_init   (ClearlooksRcStyleClass *klass);
 static GtkStyle *clearlooks_rc_style_create_style (GtkRcStyle             *rc_style);
 static guint     clearlooks_rc_style_parse        (GtkRcStyle             *rc_style,
                                                    GtkSettings            *settings,
@@ -43,11 +41,6 @@ static guint     clearlooks_rc_style_parse        (GtkRcStyle             *rc_st
 static void      clearlooks_rc_style_merge        (GtkRcStyle             *dest,
                                                    GtkRcStyle             *src);
 
-
-static GtkRcStyleClass *clearlooks_parent_rc_class;
-
-GType clearlooks_type_rc_style = 0;
-
 enum
 {
 	TOKEN_FOCUSCOLOR = G_TOKEN_LAST + 1,
@@ -56,6 +49,7 @@ enum
 	TOKEN_CONTRAST,
 	TOKEN_SUNKENMENU,
 	TOKEN_PROGRESSBARSTYLE,
+	TOKEN_RELIEFSTYLE,
 	TOKEN_MENUBARSTYLE,
 	TOKEN_TOOLBARSTYLE,
 	TOKEN_MENUITEMSTYLE,
@@ -83,6 +77,7 @@ static gchar* clearlooks_rc_symbols =
 	"contrast\0"
 	"sunkenmenubar\0"
 	"progressbarstyle\0"
+	"reliefstyle\0"
 	"menubarstyle\0"
 	"toolbarstyle\0"
 	"menuitemstyle\0"
@@ -100,27 +95,12 @@ static gchar* clearlooks_rc_symbols =
 	"TRUE\0"
 	"FALSE\0";
 
-void
-clearlooks_rc_style_register_type (GTypeModule *module)
-{
-	static const GTypeInfo object_info =
-	{
-		sizeof (ClearlooksRcStyleClass),
-		(GBaseInitFunc) NULL,
-		(GBaseFinalizeFunc) NULL,
-		(GClassInitFunc) clearlooks_rc_style_class_init,
-		NULL,           /* class_finalize */
-		NULL,           /* class_data */
-		sizeof (ClearlooksRcStyle),
-		0,              /* n_preallocs */
-		(GInstanceInitFunc) clearlooks_rc_style_init,
-		NULL
-	};
+G_DEFINE_DYNAMIC_TYPE (ClearlooksRcStyle, clearlooks_rc_style, GTK_TYPE_RC_STYLE)
 
-	clearlooks_type_rc_style = g_type_module_register_type (module,
-	                                                        GTK_TYPE_RC_STYLE,
-	                                                        "ClearlooksRcStyle",
-	                                                        &object_info, 0);
+void
+clearlooks_rc_style_register_types (GTypeModule *module)
+{
+  clearlooks_rc_style_register_type (module);
 }
 
 static void
@@ -131,6 +111,7 @@ clearlooks_rc_style_init (ClearlooksRcStyle *clearlooks_rc)
 	clearlooks_rc->flags = 0;
 
 	clearlooks_rc->contrast = 1.0;
+	clearlooks_rc->reliefstyle = 0;
 	clearlooks_rc->menubarstyle = 0;
 	clearlooks_rc->toolbarstyle = 0;
 	clearlooks_rc->animation = FALSE;
@@ -146,8 +127,8 @@ clearlooks_rc_style_finalize (GObject *object)
 	/* cleanup all the animation stuff */
 	clearlooks_animation_cleanup ();
 
-	if (G_OBJECT_CLASS (clearlooks_parent_rc_class)->finalize != NULL)
-		G_OBJECT_CLASS (clearlooks_parent_rc_class)->finalize(object);
+	if (G_OBJECT_CLASS (clearlooks_rc_style_parent_class)->finalize != NULL)
+		G_OBJECT_CLASS (clearlooks_rc_style_parent_class)->finalize (object);
 }
 #endif
 
@@ -160,8 +141,6 @@ clearlooks_rc_style_class_init (ClearlooksRcStyleClass *klass)
 	GObjectClass    *g_object_class = G_OBJECT_CLASS (klass);
 #endif
 
-	clearlooks_parent_rc_class = g_type_class_peek_parent (klass);
-
 	rc_style_class->parse = clearlooks_rc_style_parse;
 	rc_style_class->create_style = clearlooks_rc_style_create_style;
 	rc_style_class->merge = clearlooks_rc_style_merge;
@@ -171,6 +150,11 @@ clearlooks_rc_style_class_init (ClearlooksRcStyleClass *klass)
 #endif
 }
 
+static void
+clearlooks_rc_style_class_finalize (ClearlooksRcStyleClass *klass)
+{
+}
+
 static guint
 clearlooks_gtk2_rc_parse_boolean (GtkSettings *settings,
                                   GScanner     *scanner,
@@ -197,6 +181,7 @@ clearlooks_gtk2_rc_parse_boolean (GtkSettings *settings,
 static guint
 clearlooks_gtk2_rc_parse_color(GtkSettings  *settings,
                                GScanner     *scanner,
+                               GtkRcStyle   *style,
                                GdkColor     *color)
 {
 	guint token;
@@ -208,7 +193,7 @@ clearlooks_gtk2_rc_parse_color(GtkSettings  *settings,
 	if (token != G_TOKEN_EQUAL_SIGN)
 	   return G_TOKEN_EQUAL_SIGN;
 
-	return gtk_rc_parse_color (scanner, color);
+	return gtk_rc_parse_color_full (scanner, style, color);
 }
 
 static guint
@@ -241,7 +226,7 @@ clearlooks_gtk2_rc_parse_int (GtkSettings  *settings,
 {
 	guint token;
 
-	/* Skip 'sunkenmenubar' */
+	/* Skip option name */
 	token = g_scanner_get_next_token(scanner);
 
 	token = g_scanner_get_next_token(scanner);
@@ -367,11 +352,11 @@ clearlooks_rc_style_parse (GtkRcStyle *rc_style,
 		switch (token)
 		{
 			case TOKEN_FOCUSCOLOR:
-				token = clearlooks_gtk2_rc_parse_color (settings, scanner, &clearlooks_style->focus_color);
+				token = clearlooks_gtk2_rc_parse_color (settings, scanner, rc_style, &clearlooks_style->focus_color);
 				clearlooks_style->flags |= CL_FLAG_FOCUS_COLOR;
 				break;
 			case TOKEN_SCROLLBARCOLOR:
-				token = clearlooks_gtk2_rc_parse_color (settings, scanner, &clearlooks_style->scrollbar_color);
+				token = clearlooks_gtk2_rc_parse_color (settings, scanner, rc_style, &clearlooks_style->scrollbar_color);
 				clearlooks_style->flags |= CL_FLAG_SCROLLBAR_COLOR;
 				break;
 			case TOKEN_COLORIZESCROLLBAR:
@@ -382,6 +367,10 @@ clearlooks_rc_style_parse (GtkRcStyle *rc_style,
 				token = clearlooks_gtk2_rc_parse_double (settings, scanner, &clearlooks_style->contrast);
 				clearlooks_style->flags |= CL_FLAG_CONTRAST;
 				break;
+			case TOKEN_RELIEFSTYLE:
+				token = clearlooks_gtk2_rc_parse_int (settings, scanner, &clearlooks_style->reliefstyle);
+				clearlooks_style->flags |= CL_FLAG_RELIEFSTYLE;
+				break;
 			case TOKEN_MENUBARSTYLE:
 				token = clearlooks_gtk2_rc_parse_int (settings, scanner, &clearlooks_style->menubarstyle);
 				clearlooks_style->flags |= CL_FLAG_MENUBARSTYLE;
@@ -447,7 +436,7 @@ clearlooks_rc_style_merge (GtkRcStyle *dest,
 	ClearlooksRcStyle *dest_w, *src_w;
 	ClearlooksRcFlags flags;
 
-	clearlooks_parent_rc_class->merge (dest, src);
+	GTK_RC_STYLE_CLASS (clearlooks_rc_style_parent_class)->merge (dest, src);
 
 	if (!CLEARLOOKS_IS_RC_STYLE (src))
 		return;
@@ -461,6 +450,8 @@ clearlooks_rc_style_merge (GtkRcStyle *dest,
 		dest_w->style = src_w->style;
 	if (flags & CL_FLAG_CONTRAST)
 		dest_w->contrast = src_w->contrast;
+	if (flags & CL_FLAG_RELIEFSTYLE)
+		dest_w->reliefstyle = src_w->reliefstyle;
 	if (flags & CL_FLAG_MENUBARSTYLE)
 		dest_w->menubarstyle = src_w->menubarstyle;
 	if (flags & CL_FLAG_TOOLBARSTYLE)
